<template>
  <div class="mod-config">
    <basic-container>
      <el-form :inline="true" :model="dataForm" @keyup.enter.native="getDataList()">
        <el-form-item>
          <el-button v-if="permissions.process_casegroupdiscussword_add" icon="el-icon-plus" type="primary"
                     @click="addOrUpdateHandle()">新增
          </el-button>
        </el-form-item>
      </el-form>

      <div class="avue-crud">
        <el-table
          :data="dataList"
          border
          v-loading="dataListLoading">
          <el-table-column
            fixed
            prop="attendee"
            header-align="center"
            align="center"
            label="列席人员">
          </el-table-column>
          <el-table-column
            prop="beginTime"
            header-align="center"
            align="center"
            label="开始时间">
          </el-table-column>
          <el-table-column
            prop="caseNum"
            header-align="center"
            align="center"
            label="案号">
          </el-table-column>
          <el-table-column
            prop="checkCondition"
            header-align="center"
            align="center"
            label="法制审核机构负责人汇报法制审核情况">
          </el-table-column>
          <el-table-column
            prop="collectiveDiscussion"
            header-align="center"
            align="center"
            label="集体讨论决定">
          </el-table-column>
          <el-table-column
            prop="compere"
            header-align="center"
            align="center"
            label="主持人">
          </el-table-column>
          <el-table-column
            prop="comperePost"
            header-align="center"
            align="center"
            label="主持人职务">
          </el-table-column>
          <el-table-column
            prop="endTime"
            header-align="center"
            align="center"
            label="结束时间">
          </el-table-column>
          <el-table-column
            prop="hearingCondition"
            header-align="center"
            align="center"
            label="听证主持人汇报听证情况">
          </el-table-column>
          <el-table-column
            prop="opinionAndReason"
            header-align="center"
            align="center"
            label="参加讨论人员意见和理由">
          </el-table-column>
          <el-table-column
            prop="participant"
            header-align="center"
            align="center"
            label="参加人员及职务">
          </el-table-column>
          <el-table-column
            prop="participantSign"
            header-align="center"
            align="center"
            label="参加人员签名">
          </el-table-column>
          <el-table-column
            prop="place"
            header-align="center"
            align="center"
            label="地点">
          </el-table-column>
          <!--<el-table-column-->
          <!--  prop="processAjApprovalId"-->
          <!--  header-align="center"-->
          <!--  align="center"-->
          <!--  label="立案审批表ID">-->
          <!--</el-table-column>-->
          <el-table-column
            prop="processAjApprovalName"
            header-align="center"
            align="center"
            label="案件名">
          </el-table-column>
          <el-table-column
            prop="recorder"
            header-align="center"
            align="center"
            label="记录人">
          </el-table-column>
          <el-table-column
            prop="recorderPost"
            header-align="center"
            align="center"
            label="记录人职务">
          </el-table-column>
          <el-table-column
            prop="reportCondition"
            header-align="center"
            align="center"
            label="案件承办人汇报案件情况">
          </el-table-column>
          <el-table-column
            prop="reportDate"
            header-align="center"
            align="center"
            label="记录时间">
          </el-table-column>
          <el-table-column
            fixed="right"
            header-align="center"
            align="center"
            label="操作">
            <template slot-scope="scope">
              <el-button v-if="permissions.process_casegroupdiscussword_edit" type="text" size="small"
                         icon="el-icon-edit" @click="addOrUpdateHandle(scope.row.id)">修改
              </el-button>
              <el-button v-if="permissions.process_casegroupdiscussword_del" type="text" size="small"
                         icon="el-icon-delete" @click="deleteHandle(scope.row.id)">删除
              </el-button>
              <el-button v-if="permissions.process_casegroupdiscussword_wordpdf" type="text" size="small"
                         icon="el-icon-download" @click="download(scope.row.id)">下载
              </el-button>
              <el-button v-if="permissions.process_casegroupdiscussword_wordpdf" type="text" size="small" icon="el-icon-view"
                         @click="viewPdf(scope.row.id)">预览
              </el-button>
            </template>
          </el-table-column>
        </el-table>
      </div>

      <div class="avue-crud__pagination">
        <el-pagination
          @size-change="sizeChangeHandle"
          @current-change="currentChangeHandle"
          :current-page="pageIndex"
          :page-sizes="[10, 20, 50, 100]"
          :page-size="pageSize"
          :total="totalPage"
          background
          layout="total, sizes, prev, pager, next, jumper">
        </el-pagination>
      </div>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form v-if="addOrUpdateVisible" ref="addOrUpdate" @refreshDataList="getDataList"></table-form>
    </basic-container>
  </div>
</template>

<script>
  import {fetchList, delObj,createWord} from '@/api/process/casegroupdiscussword'
  import {wordToPdf, download, viewPdf} from '@/api/process/wordcommon'
  import TableForm from './casegroupdiscussword-form'
  import {mapGetters} from 'vuex'

  export default {
    data() {
      return {
        dataForm: {
          key: ''
        },
        dataList: [],
        pageIndex: 1,
        pageSize: 10,
        totalPage: 0,
        dataListLoading: false,
        addOrUpdateVisible: false
      }
    },
    components: {
      TableForm
    },
    created() {
      this.getDataList()
    },
    computed: {
      ...mapGetters(['permissions'])
    },
    methods: {
      // 获取数据列表
      getDataList() {
        this.dataListLoading = true
        fetchList(Object.assign({
          current: this.pageIndex,
          size: this.pageSize
        })).then(response => {
          console.log(response.data.data.records,"------")
          this.dataList = response.data.data.records
          this.totalPage = response.data.data.total
        })
        this.dataListLoading = false
      },
      // 每页数
      sizeChangeHandle(val) {
        this.pageSize = val
        this.pageIndex = 1
        this.getDataList()
      },
      // 当前页
      currentChangeHandle(val) {
        this.pageIndex = val
        this.getDataList()
      },
      // 新增 / 修改
      addOrUpdateHandle(id) {
        this.addOrUpdateVisible = true
        this.$nextTick(() => {
          this.$refs.addOrUpdate.init(id)
        })
      },
      // 删除
      deleteHandle(id) {
        this.$confirm('是否确认删除ID为' + id, '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          type: 'warning'
        }).then(function () {
          return delObj(id)
        }).then(data => {
          this.$message.success('删除成功')
          this.getDataList()
        })
      },

      //下载word
      download(id) {
        createWord(id).then(res => {
          if (res.data.code == 0) {
            download(res.data.data)
          }
        })
      },

      //预览pdf
      viewPdf(id) {
        createWord(id).then(res => {
          if (res.data.code == 0) {
            wordToPdf(res.data.data).then(res1 => {
              viewPdf(res1.data.data)
            })
          }
        })
      }
    }
  }
</script>
